==> digikam-4.3.0.tar.bz2: digikam-4.3.0/extra/kipi-plugins/googledrive/kipiplugin_googledrive.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Google Drive Export
Name=Google Drive Export
Name[bs]=Google Drive izvoz
Name[ca]=Exportador a Google Drive
Name[ca@valencia]=Exportador a Google Drive
Name[cs]=Export do Google Drive
Name[da]=Eksport til Google Drev
Name[de]=„Google Drive“-Export
Name[el]=Εξαγωγή στο Google Drive
Name[en_GB]=Google Drive Export
Name[es]=Exportar a Google Drive
Name[gl]=Exportación a Google Drive
Name[hu]=Google Drive exportálás
Name[is]=Google Drive útflutningur
Name[it]=Esportazione a Google Drive
Name[nb]=Google Drive eksport
Name[nl]=Exporteren naar Google Drive
Name[pl]=Eksportuj do Dysku Google
Name[pt]=Exportação para o Google Drive
Name[pt_BR]=Exportar para o Google Drive
Name[sk]=Google Drive Export
Name[sl]=Izvoz v Google Drive
Name[sv]=Export till Google Drive
Name[tr]=Google Drive Aktarımı
Name[uk]=Експорт до Google Drive
Name[x-test]=xxGoogle Drive Exportxx
Name[zh_TW]=Google 雲端硬碟匯出
Comment=A tool to export images to a remote Google Drive web service
Comment[bs]=Alat za izvoz slika na udaljeni Google Drive web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Google Drive
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Google Drive
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Google Drive
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Google Drive-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten „Google Drive“-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια υπηρεσία ιστού του Google Drive
Comment[en_GB]=A tool to export images to a remote Google Drive web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Google Drive
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Google Drive remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Google Drive webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Google Drive vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Google Drive
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Google Drive-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Google Drive-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Dysku Google
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto Google Drive
Comment[pt_BR]=Uma ferramenta para exportar imagens para um serviço da Internet Google Drive
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu Google Drive
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Google Drive
Comment[sv]=Ett verktyg för att exportera bilder till en Google Drive fjärrwebbtjänst
Comment[tr]=Resimleri uzak bir Google Drive web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Google Drive
Comment[x-test]=xxA tool to export images to a remote Google Drive web servicexx
Comment[zh_TW]=匯出影像到遠端 Google 雲端硬碟網頁服務的工具
Type=Service
Icon=kipi-googledrive
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_googledrive
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com

==> digikam-4.6.0.tar.bz2: digikam-4.6.0/extra/kipi-plugins/googledrive/kipiplugin_googledrive.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Google Drive Export
Name=Google Drive Export
Name[bs]=Google Drive izvoz
Name[ca]=Exportador a Google Drive
Name[ca@valencia]=Exportador a Google Drive
Name[cs]=Export do Google Drive
Name[da]=Eksport til Google Drev
Name[de]=„Google Drive“-Export
Name[el]=Εξαγωγή στο Google Drive
Name[en_GB]=Google Drive Export
Name[es]=Exportar a Google Drive
Name[fi]=Google Drive -vienti
Name[gl]=Exportación a Google Drive
Name[hu]=Google Drive exportálás
Name[is]=Google Drive útflutningur
Name[it]=Esportazione a Google Drive
Name[nb]=Google Drive eksport
Name[nl]=Exporteren naar Google Drive
Name[pl]=Eksportuj do Dysku Google
Name[pt]=Exportação para o Google Drive
Name[pt_BR]=Exportar para o Google Drive
Name[sk]=Google Drive Export
Name[sl]=Izvoz v Google Drive
Name[sv]=Export till Google Drive
Name[tr]=Google Drive Aktarımı
Name[uk]=Експорт до Google Drive
Name[x-test]=xxGoogle Drive Exportxx
Name[zh_TW]=Google 雲端硬碟匯出
Comment=A tool to export images to a remote Google Drive web service
Comment[bs]=Alat za izvoz slika na udaljeni Google Drive web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Google Drive
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Google Drive
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Google Drive
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Google Drive-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten „Google Drive“-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια υπηρεσία ιστού του Google Drive
Comment[en_GB]=A tool to export images to a remote Google Drive web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Google Drive
Comment[fi]=Kuvien vienti Google Drive -verkkopalveluun
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Google Drive remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Google Drive webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Google Drive vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Google Drive
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Google Drive-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Google Drive-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Dysku Google
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto Google Drive
Comment[pt_BR]=Ferramenta para exportar imagens para o Google Drive
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu Google Drive
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Google Drive
Comment[sv]=Ett verktyg för att exportera bilder till en Google Drive fjärrwebbtjänst
Comment[tr]=Resimleri uzak bir Google Drive web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Google Drive
Comment[x-test]=xxA tool to export images to a remote Google Drive web servicexx
Comment[zh_TW]=匯出影像到遠端 Google 雲端硬碟網頁服務的工具
Type=Service
Icon=kipi-googledrive
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_googledrive
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com
